==> refcomp-entities-1.6-sources.jar: fr/inra/refcomp/entities/SkillAbstract.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeHelper;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public abstract class SkillAbstract extends BusinessEntityImpl implements Skill {

    public static final List<WikittyExtension> extensions;

    public static final WikittyExtension extensionSkill;

    private static final long serialVersionUID = 7147268917373264741L;

    @Override
    public String getName() {
String value = WikittyTreeNodeHelper.getName(getWikitty());
return value;
}

    @Override
    public void setName(String name) {
String oldValue = getName();
WikittyTreeNodeHelper.setName(getWikitty(), name);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_NAME, oldValue, getName());
}

    @Override
    public Set<String> getAttachment() {
Set<String> result = WikittyTreeNodeHelper.getAttachment(getWikitty());
return result;
}

    @Override
    public void setAttachment(Set<String> attachment) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.setAttachment(getWikitty(), attachment);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void addAllAttachment(Collection<String> attachment) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.addAllAttachment(getWikitty(), attachment);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void addAttachment(String... element) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.addAttachment(getWikitty(), element);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void removeAttachment(String... element) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.removeAttachment(getWikitty(), element);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void clearAttachment() {
WikittyTreeNodeHelper.clearAttachment(getWikitty());
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, null, getAttachment());
}

    @Override
    public String getParent() {
String value = WikittyTreeNodeHelper.getParent(getWikitty());
return value;
}

    @Override
    public void setParent(String parent) {
String oldValue = getParent();
WikittyTreeNodeHelper.setParent(getWikitty(), parent);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_PARENT, oldValue, getParent());
}

    public SkillAbstract() {
        super();
}

    public SkillAbstract(Wikitty wikitty) {
        super(wikitty);
}

    public SkillAbstract(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

    static {
    
        extensionSkill = new WikittyExtension(EXT_SKILL,
                "1.0", // version
                WikittyUtil.tagValuesToMap(" alternativeName.Skill.agentSkill=\"agentSkillFromSkill\""), // tag/values
                WikittyTreeNode.EXT_WIKITTYTREENODE,
                WikittyUtil.buildFieldMapExtension( // building field map
                    ));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.addAll(WikittyTreeNodeAbstract.extensions); 
        // current after requires ones

        exts.add(extensionSkill);
        extensions = Collections.unmodifiableList(exts);

    }

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @return 
     */
    @Override
    public String toString() {
        return SkillHelper.toString(getWikitty());
}

} //SkillAbstract

==> refcomp-entities-1.7-sources.jar: fr/inra/refcomp/entities/SkillAbstract.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeHelper;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public abstract class SkillAbstract extends BusinessEntityImpl implements Skill {

    public static final List<WikittyExtension> extensions;

    public static final WikittyExtension extensionSkill;

    private static final long serialVersionUID = 7147268917373264741L;

    @Override
    public String getName() {
String value = WikittyTreeNodeHelper.getName(getWikitty());
return value;
}

    @Override
    public void setName(String name) {
String oldValue = getName();
WikittyTreeNodeHelper.setName(getWikitty(), name);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_NAME, oldValue, getName());
}

    @Override
    public Set<String> getAttachment() {
Set<String> result = WikittyTreeNodeHelper.getAttachment(getWikitty());
return result;
}

    @Override
    public void setAttachment(Set<String> attachment) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.setAttachment(getWikitty(), attachment);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void addAllAttachment(Collection<String> attachment) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.addAllAttachment(getWikitty(), attachment);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void addAttachment(String... element) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.addAttachment(getWikitty(), element);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void removeAttachment(String... element) {
Set<String> oldValue = getAttachment();
WikittyTreeNodeHelper.removeAttachment(getWikitty(), element);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, oldValue, getAttachment());
}

    @Override
    public void clearAttachment() {
WikittyTreeNodeHelper.clearAttachment(getWikitty());
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_ATTACHMENT, null, getAttachment());
}

    @Override
    public String getParent() {
String value = WikittyTreeNodeHelper.getParent(getWikitty());
return value;
}

    @Override
    public void setParent(String parent) {
String oldValue = getParent();
WikittyTreeNodeHelper.setParent(getWikitty(), parent);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_PARENT, oldValue, getParent());
}

    @Override
    public WikittyTreeNode getParent(boolean exceptionIfNotLoaded) {
WikittyTreeNode value = WikittyTreeNodeHelper.getParent(getWikitty(), exceptionIfNotLoaded);
return value;
}

    @Override
    public void setParent(WikittyTreeNode parent) {
WikittyTreeNode oldValue = getParent(false);
WikittyTreeNodeHelper.setParent(getWikitty(), parent);
getPropertyChangeSupport().firePropertyChange(WikittyTreeNode.FIELD_WIKITTYTREENODE_PARENT, oldValue, getParent());
}

    public SkillAbstract() {
        super();
}

    public SkillAbstract(Wikitty wikitty) {
        super(wikitty);
}

    public SkillAbstract(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

    static {
    
        extensionSkill = new WikittyExtension(EXT_SKILL,
                "2.0", // version
                WikittyUtil.tagValuesToMap(" alternativeName.Skill.agentSkill=\"agentSkillFromSkill\" version=\"2.0\""), // tag/values
                WikittyTreeNode.EXT_WIKITTYTREENODE,
                WikittyUtil.buildFieldMapExtension( // building field map
                    ));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.addAll(WikittyTreeNodeAbstract.extensions); 
        // current after requires ones

        exts.add(extensionSkill);
        extensions = Collections.unmodifiableList(exts);

    }

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @return 
     */
    @Override
    public String toString() {
        return SkillHelper.toString(getWikitty());
}

} //SkillAbstract
